import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  scaleTime,
  max,
  timeFormat,
  extent,
  histogram as bin,
  timeMonths,
  timeDays,
  timeHours,
  timeMinutes,
  mean,
  sum
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = { top: 20, right: 30, bottom: 65, left: 90 };
const xAxisLabelOffset = 54;
const yAxisLabelOffset = 50;

const App = () => {
  const data = [ 
      { 
         "count":"9.41920089722",
         "day":"2019-09-21T06:00:00Z"
      },
      { 
         "count":"9.41882801056",
         "day":"2019-09-21T06:15:00Z"
      },
      { 
         "count":"9.41882801056",
         "day":"2019-09-21T06:30:00Z"
      },
      { 
         "count":"9.41808223724",
         "day":"2019-09-21T06:45:00Z"
      },
      { 
         "count":"9.41808223724",
         "day":"2019-09-21T07:00:00Z"
      },
      { 
         "count":"9.41808223724",
         "day":"2019-09-21T07:15:00Z"
      },
      { 
         "count":"9.42143821716",
         "day":"2019-09-21T07:30:00Z"
      },
      { 
         "count":"9.41957378387",
         "day":"2019-09-21T07:45:00Z"
      },
      { 
         "count":"9.41770935059",
         "day":"2019-09-21T08:00:00Z"
      },
      { 
         "count":"9.41770935059",
         "day":"2019-09-21T08:15:00Z"
      },
      { 
         "count":"9.41770935059",
         "day":"2019-09-21T08:30:00Z"
      },
      { 
         "count":"9.41659069061",
         "day":"2019-09-21T08:45:00Z"
      },
      { 
         "count":"9.4167098999",
         "day":"2019-09-21T09:00:00Z"
      },
      { 
         "count":"9.41621780396",
         "day":"2019-09-21T09:15:00Z"
      },
      { 
         "count":"9.41633701324",
         "day":"2019-09-21T09:30:00Z"
      },
      { 
         "count":"9.4167098999",
         "day":"2019-09-21T09:45:00Z"
      },
      { 
         "count":"9.41708278656",
         "day":"2019-09-21T10:00:00Z"
      },
      { 
         "count":"9.41633701324",
         "day":"2019-09-21T10:15:00Z"
      },
      { 
         "count":"9.41596412659",
         "day":"2019-09-21T10:30:00Z"
      },
      { 
         "count":"9.41559123993",
         "day":"2019-09-21T10:45:00Z"
      },
      { 
         "count":"9.41633701324",
         "day":"2019-09-21T11:00:00Z"
      },
      { 
         "count":"9.41596412659",
         "day":"2019-09-21T11:15:00Z"
      },
      { 
         "count":"9.41559123993",
         "day":"2019-09-21T11:30:00Z"
      },
      { 
         "count":"9.41559123993",
         "day":"2019-09-21T11:45:00Z"
      },
      { 
         "count":"9.41633701324",
         "day":"2019-09-21T12:00:00Z"
      },
      { 
         "count":"9.41633701324",
         "day":"2019-09-21T12:15:00Z"
      },
      { 
         "count":"9.41757583618",
         "day":"2019-09-21T12:30:00Z"
      },
      { 
         "count":"9.42018699646",
         "day":"2019-09-21T12:45:00Z"
      },
      { 
         "count":"9.41720294952",
         "day":"2019-09-21T13:00:00Z"
      },
      { 
         "count":"9.41683006287",
         "day":"2019-09-21T13:15:00Z"
      },
      { 
         "count":"9.41720294952",
         "day":"2019-09-21T13:30:00Z"
      },
      { 
         "count":"9.41645717621",
         "day":"2019-09-21T13:45:00Z"
      },
      { 
         "count":"9.41720294952",
         "day":"2019-09-21T14:00:00Z"
      },
      { 
         "count":"9.41683006287",
         "day":"2019-09-21T14:15:00Z"
      },
      { 
         "count":"9.41769504547",
         "day":"2019-09-21T14:30:00Z"
      },
      { 
         "count":"9.41769504547",
         "day":"2019-09-21T14:45:00Z"
      },
      { 
         "count":"9.4180688858",
         "day":"2019-09-21T15:00:00Z"
      },
      { 
         "count":"9.4180688858",
         "day":"2019-09-21T15:15:00Z"
      },
      { 
         "count":"9.41769504547",
         "day":"2019-09-21T15:30:01Z"
      },
      { 
         "count":"9.41732215881",
         "day":"2019-09-21T15:45:00Z"
      },
      { 
         "count":"9.41732215881",
         "day":"2019-09-21T16:00:00Z"
      },
      { 
         "count":"9.41732215881",
         "day":"2019-09-21T16:15:00Z"
      },
      { 
         "count":"9.4180688858",
         "day":"2019-09-21T16:30:00Z"
      },
      { 
         "count":"9.41844177246",
         "day":"2019-09-21T16:45:00Z"
      },
      { 
         "count":"9.4180688858",
         "day":"2019-09-21T17:00:00Z"
      },
      { 
         "count":"9.41856098175",
         "day":"2019-09-21T17:15:00Z"
      },
      { 
         "count":"9.41856098175",
         "day":"2019-09-21T17:30:00Z"
      },
      { 
         "count":"9.42191982269",
         "day":"2019-09-21T17:45:00Z"
      },
      { 
         "count":"9.42005252838",
         "day":"2019-09-21T18:00:00Z"
      },
      { 
         "count":"9.41893482208",
         "day":"2019-09-21T18:15:00Z"
      },
      { 
         "count":"9.41893482208",
         "day":"2019-09-21T18:30:00Z"
      },
      { 
         "count":"9.41930770874",
         "day":"2019-09-21T18:45:00Z"
      },
      { 
         "count":"9.41930770874",
         "day":"2019-09-21T19:00:00Z"
      },
      { 
         "count":"9.41930770874",
         "day":"2019-09-21T19:15:00Z"
      },
      { 
         "count":"9.41930770874",
         "day":"2019-09-21T19:30:00Z"
      },
      { 
         "count":"9.41930770874",
         "day":"2019-09-21T19:45:00Z"
      },
      { 
         "count":"9.41930770874",
         "day":"2019-09-21T20:00:00Z"
      },
      { 
         "count":"9.42042732239",
         "day":"2019-09-21T20:15:00Z"
      },
      { 
         "count":"9.42042732239",
         "day":"2019-09-21T20:30:00Z"
      },
      { 
         "count":"9.42042732239",
         "day":"2019-09-21T20:45:00Z"
      },
      { 
         "count":"9.42005252838",
         "day":"2019-09-21T21:00:00Z"
      },
      { 
         "count":"9.42042732239",
         "day":"2019-09-21T21:15:00Z"
      },
      { 
         "count":"9.42042732239",
         "day":"2019-09-21T21:30:00Z"
      },
      { 
         "count":"9.42080020905",
         "day":"2019-09-21T21:45:00Z"
      },
      { 
         "count":"9.42042732239",
         "day":"2019-09-21T22:00:00Z"
      },
      { 
         "count":"9.4196805954",
         "day":"2019-09-21T22:15:00Z"
      },
      { 
         "count":"9.42042732239",
         "day":"2019-09-21T22:30:00Z"
      },
      { 
         "count":"9.42191982269",
         "day":"2019-09-21T22:45:00Z"
      },
      { 
         "count":"9.42378520966",
         "day":"2019-09-21T23:00:00Z"
      },
      { 
         "count":"9.42117404938",
         "day":"2019-09-21T23:15:00Z"
      },
      { 
         "count":"9.42080020905",
         "day":"2019-09-21T23:30:00Z"
      },
      { 
         "count":"9.42117404938",
         "day":"2019-09-21T23:45:00Z"
      },
      { 
         "count":"9.42117404938",
         "day":"2019-09-22T00:00:00Z"
      },
      { 
         "count":"9.42154693604",
         "day":"2019-09-22T00:15:00Z"
      },
      { 
         "count":"9.42105293274",
         "day":"2019-09-22T00:30:00Z"
      },
      { 
         "count":"9.4214258194",
         "day":"2019-09-22T00:45:00Z"
      },
      { 
         "count":"9.42105293274",
         "day":"2019-09-22T01:00:00Z"
      },
      { 
         "count":"9.42179965973",
         "day":"2019-09-22T01:15:00Z"
      },
      { 
         "count":"9.42254543304",
         "day":"2019-09-22T01:30:00Z"
      },
      { 
         "count":"9.42254543304",
         "day":"2019-09-22T01:45:00Z"
      },
      { 
         "count":"9.42254543304",
         "day":"2019-09-22T02:00:00Z"
      },
      { 
         "count":"9.42217254639",
         "day":"2019-09-22T02:15:00Z"
      },
      { 
         "count":"9.42329120636",
         "day":"2019-09-22T02:30:00Z"
      },
      { 
         "count":"9.42366504669",
         "day":"2019-09-22T02:45:00Z"
      },
      { 
         "count":"9.42366504669",
         "day":"2019-09-22T03:00:00Z"
      },
      { 
         "count":"9.42403793335",
         "day":"2019-09-22T03:15:00Z"
      },
      { 
         "count":"9.42441082001",
         "day":"2019-09-22T03:30:00Z"
      },
      { 
         "count":"9.42403793335",
         "day":"2019-09-22T03:45:00Z"
      },
      { 
         "count":"9.42851352692",
         "day":"2019-09-22T04:00:00Z"
      },
      { 
         "count":"9.42627620697",
         "day":"2019-09-22T04:15:00Z"
      },
      { 
         "count":"9.42664909363",
         "day":"2019-09-22T04:30:00Z"
      },
      { 
         "count":"9.42702293396",
         "day":"2019-09-22T04:45:00Z"
      },
      { 
         "count":"9.42739582062",
         "day":"2019-09-22T05:00:00Z"
      },
      { 
         "count":"9.42826366425",
         "day":"2019-09-22T05:15:00Z"
      },
      { 
         "count":"9.4286365509",
         "day":"2019-09-22T05:30:00Z"
      },
      { 
         "count":"9.42938327789",
         "day":"2019-09-22T05:45:00Z"
      },
      { 
         "count":"9.4286365509",
         "day":"2019-09-22T06:00:00Z"
      },
      { 
         "count":"9.42900943756",
         "day":"2019-09-22T06:15:00Z"
      },
      { 
         "count":"9.42975616455",
         "day":"2019-09-22T06:30:00Z"
      },
      { 
         "count":"9.43012905121",
         "day":"2019-09-22T06:45:00Z"
      },
      { 
         "count":"9.43062496185",
         "day":"2019-09-22T07:00:00Z"
      },
      { 
         "count":"9.43137168884",
         "day":"2019-09-22T07:15:00Z"
      },
      { 
         "count":"9.4317445755",
         "day":"2019-09-22T07:30:00Z"
      },
      { 
         "count":"9.43249130249",
         "day":"2019-09-22T07:45:00Z"
      },
      { 
         "count":"9.43249130249",
         "day":"2019-09-22T08:00:00Z"
      },
      { 
         "count":"9.43361091614",
         "day":"2019-09-22T08:15:00Z"
      },
      { 
         "count":"9.43410682678",
         "day":"2019-09-22T08:30:00Z"
      },
      { 
         "count":"9.43485355377",
         "day":"2019-09-22T08:45:00Z"
      },
      { 
         "count":"9.43709373474",
         "day":"2019-09-22T09:00:00Z"
      },
      { 
         "count":"9.43933391571",
         "day":"2019-09-22T09:15:00Z"
      },
      { 
         "count":"9.43672084808",
         "day":"2019-09-22T09:30:00Z"
      },
      { 
         "count":"9.4374666214",
         "day":"2019-09-22T09:45:00Z"
      },
      { 
         "count":"9.43821334839",
         "day":"2019-09-22T10:00:00Z"
      },
      { 
         "count":"9.43908405304",
         "day":"2019-09-22T10:15:00Z"
      },
      { 
         "count":"9.43945789337",
         "day":"2019-09-22T10:30:00Z"
      },
      { 
         "count":"9.44020462036",
         "day":"2019-09-22T10:45:00Z"
      },
      { 
         "count":"9.44057846069",
         "day":"2019-09-22T11:00:00Z"
      },
      { 
         "count":"9.44095134735",
         "day":"2019-09-22T11:15:00Z"
      },
      { 
         "count":"9.44169807434",
         "day":"2019-09-22T11:30:00Z"
      },
      { 
         "count":"9.44219589233",
         "day":"2019-09-22T11:45:00Z"
      },
      { 
         "count":"9.44331645966",
         "day":"2019-09-22T12:00:00Z"
      },
      { 
         "count":"9.44406318665",
         "day":"2019-09-22T12:15:00Z"
      },
      { 
         "count":"9.44331645966",
         "day":"2019-09-22T12:30:00Z"
      },
      { 
         "count":"9.44493579865",
         "day":"2019-09-22T12:45:00Z"
      },
      { 
         "count":"9.44568252563",
         "day":"2019-09-22T13:00:00Z"
      },
      { 
         "count":"9.44605636597",
         "day":"2019-09-22T13:15:00Z"
      },
      { 
         "count":"9.44642925262",
         "day":"2019-09-22T13:30:00Z"
      },
      { 
         "count":"9.44717693329",
         "day":"2019-09-22T13:45:00Z"
      },
      { 
         "count":"9.44754981995",
         "day":"2019-09-22T14:00:00Z"
      },
      { 
         "count":"9.45165920258",
         "day":"2019-09-22T14:15:00Z"
      },
      { 
         "count":"9.45215988159",
         "day":"2019-09-22T14:30:00Z"
      },
      { 
         "count":"9.45066547394",
         "day":"2019-09-22T14:45:00Z"
      },
      { 
         "count":"9.45178604126",
         "day":"2019-09-22T15:00:00Z"
      },
      { 
         "count":"9.45328044891",
         "day":"2019-09-22T15:15:00Z"
      },
      { 
         "count":"9.45415496826",
         "day":"2019-09-22T15:30:00Z"
      },
      { 
         "count":"9.45527553558",
         "day":"2019-09-22T15:45:00Z"
      },
      { 
         "count":"9.45527553558",
         "day":"2019-09-22T16:00:00Z"
      },
      { 
         "count":"9.45639705658",
         "day":"2019-09-22T16:15:00Z"
      },
      { 
         "count":"9.45677089691",
         "day":"2019-09-22T16:30:00Z"
      },
      { 
         "count":"9.45826530457",
         "day":"2019-09-22T16:45:00Z"
      },
      { 
         "count":"9.45901298523",
         "day":"2019-09-22T17:00:00Z"
      },
      { 
         "count":"9.46063613892",
         "day":"2019-09-22T17:15:00Z"
      },
      { 
         "count":"9.46026229858",
         "day":"2019-09-22T17:30:00Z"
      },
      { 
         "count":"9.46063613892",
         "day":"2019-09-22T17:45:00Z"
      },
      { 
         "count":"9.46138381958",
         "day":"2019-09-22T18:00:00Z"
      },
      { 
         "count":"9.46175765991",
         "day":"2019-09-22T18:15:00Z"
      },
      { 
         "count":"9.46250534058",
         "day":"2019-09-22T18:30:00Z"
      },
      { 
         "count":"9.46325302124",
         "day":"2019-09-22T18:45:00Z"
      },
      { 
         "count":"9.46325302124",
         "day":"2019-09-22T19:00:00Z"
      },
      { 
         "count":"9.46586894989",
         "day":"2019-09-22T19:15:00Z"
      },
      { 
         "count":"9.46848583221",
         "day":"2019-09-22T19:30:00Z"
      },
      { 
         "count":"9.46674633026",
         "day":"2019-09-22T19:45:00Z"
      },
      { 
         "count":"9.46624279022",
         "day":"2019-09-22T20:00:00Z"
      },
      { 
         "count":"9.46674633026",
         "day":"2019-09-22T20:15:00Z"
      },
      { 
         "count":"9.46712017059",
         "day":"2019-09-22T20:30:00Z"
      },
      { 
         "count":"9.46786785126",
         "day":"2019-09-22T20:45:00Z"
      },
      { 
         "count":"9.46898937225",
         "day":"2019-09-22T21:00:00Z"
      },
      { 
         "count":"9.46936321259",
         "day":"2019-09-22T21:15:00Z"
      },
      { 
         "count":"9.46936321259",
         "day":"2019-09-22T21:30:00Z"
      },
      { 
         "count":"9.47011089325",
         "day":"2019-09-22T21:45:00Z"
      },
      { 
         "count":"9.47048473358",
         "day":"2019-09-22T22:00:00Z"
      },
      { 
         "count":"9.47085857391",
         "day":"2019-09-22T22:15:00Z"
      },
      { 
         "count":"9.47098922729",
         "day":"2019-09-22T22:30:00Z"
      },
      { 
         "count":"9.4724855423",
         "day":"2019-09-22T22:45:00Z"
      },
      { 
         "count":"9.4724855423",
         "day":"2019-09-22T23:00:00Z"
      },
      { 
         "count":"9.47285938263",
         "day":"2019-09-22T23:15:00Z"
      },
      { 
         "count":"9.47285938263",
         "day":"2019-09-22T23:30:00Z"
      },
      { 
         "count":"9.47323322296",
         "day":"2019-09-22T23:45:00Z"
      },
      { 
         "count":"9.47323322296",
         "day":"2019-09-23T00:00:00Z"
      },
      { 
         "count":"9.47360706329",
         "day":"2019-09-23T00:15:00Z"
      },
      { 
         "count":"9.47809410095",
         "day":"2019-09-23T00:30:00Z"
      },
      { 
         "count":"9.47785282135",
         "day":"2019-09-23T00:45:00Z"
      },
      { 
         "count":"9.47598266602",
         "day":"2019-09-23T01:00:00Z"
      },
      { 
         "count":"9.47635746002",
         "day":"2019-09-23T01:15:00Z"
      },
      { 
         "count":"9.47635746002",
         "day":"2019-09-23T01:30:00Z"
      },
      { 
         "count":"9.47747802734",
         "day":"2019-09-23T01:45:00Z"
      },
      { 
         "count":"9.47785282135",
         "day":"2019-09-23T02:00:00Z"
      },
      { 
         "count":"9.47860145569",
         "day":"2019-09-23T02:15:00Z"
      },
      { 
         "count":"9.47873210907",
         "day":"2019-09-23T02:30:00Z"
      },
      { 
         "count":"9.47948074341",
         "day":"2019-09-23T02:45:00Z"
      },
      { 
         "count":"9.48022937775",
         "day":"2019-09-23T03:00:00Z"
      },
      { 
         "count":"9.48097705841",
         "day":"2019-09-23T03:15:00Z"
      },
      { 
         "count":"9.48185825348",
         "day":"2019-09-23T03:30:00Z"
      },
      { 
         "count":"9.48260593414",
         "day":"2019-09-23T03:45:00Z"
      },
      { 
         "count":"9.48372936249",
         "day":"2019-09-23T04:00:00Z"
      },
      { 
         "count":"9.48410320282",
         "day":"2019-09-23T04:15:00Z"
      },
      { 
         "count":"9.4857339859",
         "day":"2019-09-23T04:30:00Z"
      },
      { 
         "count":"9.48648166656",
         "day":"2019-09-23T04:45:00Z"
      },
      { 
         "count":"9.4872303009",
         "day":"2019-09-23T05:00:00Z"
      },
      { 
         "count":"9.48886203766",
         "day":"2019-09-23T05:15:00Z"
      },
      { 
         "count":"9.49110794067",
         "day":"2019-09-23T05:30:00Z"
      },
      { 
         "count":"9.49447631836",
         "day":"2019-09-23T05:45:00Z"
      },
      { 
         "count":"9.49148178101",
         "day":"2019-09-23T06:00:00Z"
      },
      { 
         "count":"9.49273967743",
         "day":"2019-09-23T06:15:00Z"
      },
      { 
         "count":"9.49386310577",
         "day":"2019-09-23T06:30:00Z"
      },
      { 
         "count":"9.49536037445",
         "day":"2019-09-23T06:45:00Z"
      },
      { 
         "count":"9.49610900879",
         "day":"2019-09-23T07:00:00Z"
      },
      { 
         "count":"9.49774360657",
         "day":"2019-09-23T07:15:00Z"
      },
      { 
         "count":"9.4981174469",
         "day":"2019-09-23T07:30:00Z"
      },
      { 
         "count":"9.50012683868",
         "day":"2019-09-23T07:45:00Z"
      },
      { 
         "count":"9.50162506104",
         "day":"2019-09-23T08:00:00Z"
      },
      { 
         "count":"9.50237369537",
         "day":"2019-09-23T08:15:00Z"
      },
      { 
         "count":"9.50349807739",
         "day":"2019-09-23T08:30:00Z"
      },
      { 
         "count":"9.50475883484",
         "day":"2019-09-23T08:45:00Z"
      },
      { 
         "count":"9.50588321686",
         "day":"2019-09-23T09:00:00Z"
      },
      { 
         "count":"9.5066318512",
         "day":"2019-09-23T09:15:00Z"
      },
      { 
         "count":"9.50826931",
         "day":"2019-09-23T09:30:00Z"
      },
      { 
         "count":"9.50939273834",
         "day":"2019-09-23T09:45:00Z"
      },
      { 
         "count":"9.5099067688",
         "day":"2019-09-23T10:00:00Z"
      },
      { 
         "count":"9.51130867004",
         "day":"2019-09-23T10:15:00Z"
      },
      { 
         "count":"9.51233768463",
         "day":"2019-09-23T10:30:00Z"
      },
      { 
         "count":"9.51824474335",
         "day":"2019-09-23T10:45:00Z"
      },
      { 
         "count":"9.51852703094",
         "day":"2019-09-23T11:00:00Z"
      },
      { 
         "count":"9.51918411255",
         "day":"2019-09-23T11:15:00Z"
      },
      { 
         "count":"9.5229883194",
         "day":"2019-09-23T11:30:00Z"
      },
      { 
         "count":"9.52590370178",
         "day":"2019-09-23T11:45:00Z"
      },
      { 
         "count":"9.52994918823",
         "day":"2019-09-23T12:00:00Z"
      },
      { 
         "count":"9.53399753571",
         "day":"2019-09-23T12:15:00Z"
      },
      { 
         "count":"9.53805065155",
         "day":"2019-09-23T12:30:00Z"
      },
      { 
         "count":"9.54210567474",
         "day":"2019-09-23T12:45:00Z"
      },
      { 
         "count":"9.54654121399",
         "day":"2019-09-23T13:00:00Z"
      },
      { 
         "count":"9.55045604706",
         "day":"2019-09-23T13:15:00Z"
      },
      { 
         "count":"9.55452060699",
         "day":"2019-09-23T13:30:00Z"
      },
      { 
         "count":"9.55806255341",
         "day":"2019-09-23T13:45:00Z"
      },
      { 
         "count":"9.56047439575",
         "day":"2019-09-23T14:00:00Z"
      },
      { 
         "count":"9.5632648468",
         "day":"2019-09-23T14:15:00Z"
      },
      { 
         "count":"9.56530094147",
         "day":"2019-09-23T14:30:00Z"
      },
      { 
         "count":"9.56771564484",
         "day":"2019-09-23T14:45:00Z"
      },
      { 
         "count":"9.56809329987",
         "day":"2019-09-23T15:00:01Z"
      },
      { 
         "count":"9.56899929047",
         "day":"2019-09-23T15:15:00Z"
      },
      { 
         "count":"9.5693769455",
         "day":"2019-09-23T15:30:00Z"
      },
      { 
         "count":"9.57141590118",
         "day":"2019-09-23T15:45:00Z"
      },
      { 
         "count":"9.57443523407",
         "day":"2019-09-23T16:00:00Z"
      },
      { 
         "count":"9.57141590118",
         "day":"2019-09-23T16:15:00Z"
      },
      { 
         "count":"9.57217025757",
         "day":"2019-09-23T16:30:00Z"
      },
      { 
         "count":"9.57179355621",
         "day":"2019-09-23T16:45:00Z"
      },
      { 
         "count":"9.57088661194",
         "day":"2019-09-23T17:00:00Z"
      },
      { 
         "count":"9.57164096832",
         "day":"2019-09-23T17:15:00Z"
      },
      { 
         "count":"9.57201862335",
         "day":"2019-09-23T17:30:00Z"
      },
      { 
         "count":"9.57148838043",
         "day":"2019-09-23T17:45:00Z"
      },
      { 
         "count":"9.57058238983",
         "day":"2019-09-23T18:00:00Z"
      },
      { 
         "count":"9.59321594238",
         "day":"2019-09-23T18:15:00Z"
      },
      { 
         "count":"9.59532260895",
         "day":"2019-09-23T18:30:00Z"
      },
      { 
         "count":"9.59441184998",
         "day":"2019-09-23T18:45:00Z"
      },
      { 
         "count":"9.593501091",
         "day":"2019-09-23T19:00:00Z"
      },
      { 
         "count":"9.59463214874",
         "day":"2019-09-23T19:15:00Z"
      },
      { 
         "count":"9.59485054016",
         "day":"2019-09-23T19:30:00Z"
      },
      { 
         "count":"9.59469509125",
         "day":"2019-09-23T19:45:00Z"
      },
      { 
         "count":"9.59453868866",
         "day":"2019-09-23T20:00:00Z"
      },
      { 
         "count":"9.5943813324",
         "day":"2019-09-23T20:15:00Z"
      },
      { 
         "count":"9.59422492981",
         "day":"2019-09-23T20:30:00Z"
      },
      { 
         "count":"9.59331512451",
         "day":"2019-09-23T20:45:00Z"
      },
      { 
         "count":"9.59504127502",
         "day":"2019-09-23T21:00:00Z"
      },
      { 
         "count":"9.59526062012",
         "day":"2019-09-23T21:15:00Z"
      },
      { 
         "count":"9.59209346771",
         "day":"2019-09-23T21:30:00Z"
      },
      { 
         "count":"9.59171772003",
         "day":"2019-09-23T21:45:00Z"
      },
      { 
         "count":"9.59043312073",
         "day":"2019-09-23T22:00:00Z"
      },
      { 
         "count":"9.5891494751",
         "day":"2019-09-23T22:15:00Z"
      },
      { 
         "count":"9.5863609314",
         "day":"2019-09-23T22:30:00Z"
      },
      { 
         "count":"9.58357334137",
         "day":"2019-09-23T22:45:00Z"
      },
      { 
         "count":"9.58003616333",
         "day":"2019-09-23T23:00:00Z"
      },
      { 
         "count":"9.57740497589",
         "day":"2019-09-23T23:15:00Z"
      },
      { 
         "count":"9.5738697052",
         "day":"2019-09-23T23:30:00Z"
      },
      { 
         "count":"9.5699596405",
         "day":"2019-09-23T23:45:00Z"
      },
      { 
         "count":"9.56582641602",
         "day":"2019-09-24T00:00:00Z"
      },
      { 
         "count":"9.56116676331",
         "day":"2019-09-24T00:15:00Z"
      },
      { 
         "count":"9.55628299713",
         "day":"2019-09-24T00:30:00Z"
      },
      { 
         "count":"9.5520029068",
         "day":"2019-09-24T00:45:00Z"
      },
      { 
         "count":"9.54749488831",
         "day":"2019-09-24T01:00:00Z"
      },
      { 
         "count":"9.543217659",
         "day":"2019-09-24T01:15:00Z"
      },
      { 
         "count":"9.53908729553",
         "day":"2019-09-24T01:30:00Z"
      },
      { 
         "count":"9.53593826294",
         "day":"2019-09-24T01:45:00Z"
      },
      { 
         "count":"9.53255939484",
         "day":"2019-09-24T02:00:00Z"
      },
      { 
         "count":"9.53255939484",
         "day":"2019-09-24T02:15:00Z"
      },
      { 
         "count":"9.52603435516",
         "day":"2019-09-24T02:30:00Z"
      },
      { 
         "count":"9.52152919769",
         "day":"2019-09-24T02:45:00Z"
      },
      { 
         "count":"9.51852703094",
         "day":"2019-09-24T03:00:00Z"
      },
      { 
         "count":"9.51538276672",
         "day":"2019-09-24T03:15:00Z"
      },
      { 
         "count":"9.51275634766",
         "day":"2019-09-24T03:30:00Z"
      },
      { 
         "count":"9.50937843323",
         "day":"2019-09-24T03:45:00Z"
      },
      { 
         "count":"9.50750160217",
         "day":"2019-09-24T04:00:00Z"
      },
      { 
         "count":"9.50562572479",
         "day":"2019-09-24T04:15:00Z"
      },
      { 
         "count":"9.50337409973",
         "day":"2019-09-24T04:30:00Z"
      },
      { 
         "count":"9.50149726868",
         "day":"2019-09-24T04:45:00Z"
      },
      { 
         "count":"9.4999961853",
         "day":"2019-09-24T05:00:00Z"
      },
      { 
         "count":"9.49849510193",
         "day":"2019-09-24T05:15:00Z"
      },
      { 
         "count":"9.49624252319",
         "day":"2019-09-24T05:30:00Z"
      },
      { 
         "count":"9.4951171875",
         "day":"2019-09-24T05:45:00Z"
      },
      { 
         "count":"9.49361610413",
         "day":"2019-09-24T06:00:00Z"
      },
      { 
         "count":"9.49286460876",
         "day":"2019-09-24T06:15:00Z"
      },
      { 
         "count":"9.49211406708",
         "day":"2019-09-24T06:30:00Z"
      },
      { 
         "count":"9.49173927307",
         "day":"2019-09-24T06:45:00Z"
      },
      { 
         "count":"9.4902381897",
         "day":"2019-09-24T07:00:00Z"
      },
      { 
         "count":"9.49136352539",
         "day":"2019-09-24T07:15:00Z"
      },
      { 
         "count":"9.49173927307",
         "day":"2019-09-24T07:30:00Z"
      },
      { 
         "count":"9.48761081696",
         "day":"2019-09-24T07:45:00Z"
      },
      { 
         "count":"9.48798561096",
         "day":"2019-09-24T08:00:00Z"
      },
      { 
         "count":"9.48774528503",
         "day":"2019-09-24T08:15:00Z"
      },
      { 
         "count":"9.48736953735",
         "day":"2019-09-24T08:30:00Z"
      },
      { 
         "count":"9.48699474335",
         "day":"2019-09-24T08:45:00Z"
      },
      { 
         "count":"9.48661899567",
         "day":"2019-09-24T09:00:00Z"
      },
      { 
         "count":"9.4854927063",
         "day":"2019-09-24T09:15:00Z"
      },
      { 
         "count":"9.48600196838",
         "day":"2019-09-24T09:30:00Z"
      },
      { 
         "count":"9.48576068878",
         "day":"2019-09-24T09:45:00Z"
      },
      { 
         "count":"9.48551940918",
         "day":"2019-09-24T10:00:00Z"
      },
      { 
         "count":"9.48653888702",
         "day":"2019-09-24T10:15:00Z"
      },
      { 
         "count":"9.48844623566",
         "day":"2019-09-24T10:30:00Z"
      },
      { 
         "count":"9.48909187317",
         "day":"2019-09-24T10:45:00Z"
      },
      { 
         "count":"9.49124336243",
         "day":"2019-09-24T11:00:00Z"
      },
      { 
         "count":"9.49339675903",
         "day":"2019-09-24T11:15:00Z"
      },
      { 
         "count":"9.49555206299",
         "day":"2019-09-24T11:30:00Z"
      },
      { 
         "count":"9.49808502197",
         "day":"2019-09-24T11:45:00Z"
      },
      { 
         "count":"9.50123691559",
         "day":"2019-09-24T12:00:00Z"
      },
      { 
         "count":"9.50490474701",
         "day":"2019-09-24T12:15:00Z"
      },
      { 
         "count":"9.51234817505",
         "day":"2019-09-24T12:30:00Z"
      },
      { 
         "count":"9.51451396942",
         "day":"2019-09-24T12:45:00Z"
      },
      { 
         "count":"9.51654243469",
         "day":"2019-09-24T13:00:00Z"
      },
      { 
         "count":"9.52097606659",
         "day":"2019-09-24T13:15:00Z"
      },
      { 
         "count":"9.52579307556",
         "day":"2019-09-24T13:30:00Z"
      },
      { 
         "count":"9.53046894073",
         "day":"2019-09-24T13:45:00Z"
      },
      { 
         "count":"9.53476905823",
         "day":"2019-09-24T14:00:00Z"
      },
      { 
         "count":"9.53816986084",
         "day":"2019-09-24T14:15:00Z"
      },
      { 
         "count":"9.54209423065",
         "day":"2019-09-24T14:30:00Z"
      },
      { 
         "count":"9.54549598694",
         "day":"2019-09-24T14:45:00Z"
      },
      { 
         "count":"9.54851913452",
         "day":"2019-09-24T15:00:00Z"
      },
      { 
         "count":"9.55192089081",
         "day":"2019-09-24T15:15:00Z"
      },
      { 
         "count":"9.55290603638",
         "day":"2019-09-24T15:30:00Z"
      },
      { 
         "count":"9.55479621887",
         "day":"2019-09-24T15:45:00Z"
      },
      { 
         "count":"9.5561580658",
         "day":"2019-09-24T16:00:00Z"
      },
      { 
         "count":"9.55842494965",
         "day":"2019-09-24T16:15:00Z"
      },
      { 
         "count":"9.55865287781",
         "day":"2019-09-24T16:30:00Z"
      },
      { 
         "count":"9.55963611603",
         "day":"2019-09-24T16:45:00Z"
      },
      { 
         "count":"9.56024169922",
         "day":"2019-09-24T17:00:00Z"
      },
      { 
         "count":"9.56046867371",
         "day":"2019-09-24T17:15:00Z"
      },
      { 
         "count":"9.56182861328",
         "day":"2019-09-24T17:30:00Z"
      },
      { 
         "count":"9.56356525421",
         "day":"2019-09-24T17:45:00Z"
      },
      { 
         "count":"9.56039619446",
         "day":"2019-09-24T18:00:00Z"
      },
      { 
         "count":"9.56100082397",
         "day":"2019-09-24T18:15:00Z"
      },
      { 
         "count":"9.56085109711",
         "day":"2019-09-24T18:30:00Z"
      },
      { 
         "count":"9.56145572662",
         "day":"2019-09-24T18:45:00Z"
      },
      { 
         "count":"9.56092834473",
         "day":"2019-09-24T19:00:00Z"
      },
      { 
         "count":"9.56002521515",
         "day":"2019-09-24T19:15:00Z"
      },
      { 
         "count":"9.55874538422",
         "day":"2019-09-24T19:30:00Z"
      },
      { 
         "count":"9.55708885193",
         "day":"2019-09-24T19:45:00Z"
      },
      { 
         "count":"9.55505657196",
         "day":"2019-09-24T20:00:00Z"
      },
      { 
         "count":"9.55340194702",
         "day":"2019-09-24T20:15:00Z"
      },
      { 
         "count":"9.55024242401",
         "day":"2019-09-24T20:30:00Z"
      },
      { 
         "count":"9.54557800293",
         "day":"2019-09-24T20:45:00Z"
      },
      { 
         "count":"9.54204463959",
         "day":"2019-09-24T21:00:00Z"
      },
      { 
         "count":"9.53813552856",
         "day":"2019-09-24T21:15:00Z"
      },
      { 
         "count":"9.53310203552",
         "day":"2019-09-24T21:30:00Z"
      },
      { 
         "count":"9.52882099152",
         "day":"2019-09-24T21:45:00Z"
      },
      { 
         "count":"9.52506065369",
         "day":"2019-09-24T22:00:00Z"
      },
      { 
         "count":"9.52190971375",
         "day":"2019-09-24T22:15:00Z"
      },
      { 
         "count":"9.51725769043",
         "day":"2019-09-24T22:30:00Z"
      },
      { 
         "count":"9.51636505127",
         "day":"2019-09-24T22:45:00Z"
      },
      { 
         "count":"9.5137348175",
         "day":"2019-09-24T23:00:00Z"
      },
      { 
         "count":"9.50908565521",
         "day":"2019-09-24T23:15:00Z"
      },
      { 
         "count":"9.50720596313",
         "day":"2019-09-24T23:30:00Z"
      },
      { 
         "count":"9.50556564331",
         "day":"2019-09-24T23:45:00Z"
      },
      { 
         "count":"9.50354862213",
         "day":"2019-09-25T00:00:00Z"
      },
      { 
         "count":"9.50317287445",
         "day":"2019-09-25T00:15:00Z"
      },
      { 
         "count":"9.50228500366",
         "day":"2019-09-25T00:30:00Z"
      },
      { 
         "count":"9.50190925598",
         "day":"2019-09-25T00:45:00Z"
      },
      { 
         "count":"9.50153446198",
         "day":"2019-09-25T01:00:00Z"
      },
      { 
         "count":"9.50102043152",
         "day":"2019-09-25T01:15:00Z"
      },
      { 
         "count":"9.5013961792",
         "day":"2019-09-25T01:30:00Z"
      },
      { 
         "count":"9.50050830841",
         "day":"2019-09-25T01:45:00Z"
      },
      { 
         "count":"9.50013256073",
         "day":"2019-09-25T02:00:00Z"
      },
      { 
         "count":"9.50050830841",
         "day":"2019-09-25T02:15:00Z"
      },
      { 
         "count":"9.4999961853",
         "day":"2019-09-25T02:30:00Z"
      },
      { 
         "count":"9.50149726868",
         "day":"2019-09-25T02:45:00Z"
      },
      { 
         "count":"9.50187206268",
         "day":"2019-09-25T03:00:00Z"
      },
      { 
         "count":"9.50173473358",
         "day":"2019-09-25T03:15:00Z"
      },
      { 
         "count":"9.50248527527",
         "day":"2019-09-25T03:30:00Z"
      },
      { 
         "count":"9.50286102295",
         "day":"2019-09-25T03:45:00Z"
      },
      { 
         "count":"9.50811386108",
         "day":"2019-09-25T04:00:00Z"
      },
      { 
         "count":"9.50347328186",
         "day":"2019-09-25T04:15:00Z"
      },
      { 
         "count":"9.50384902954",
         "day":"2019-09-25T04:30:00Z"
      },
      { 
         "count":"9.50436115265",
         "day":"2019-09-25T04:45:00Z"
      },
      { 
         "count":"9.50473690033",
         "day":"2019-09-25T05:00:00Z"
      },
      { 
         "count":"9.5062379837",
         "day":"2019-09-25T05:15:00Z"
      },
      { 
         "count":"9.50497436523",
         "day":"2019-09-25T05:30:00Z"
      },
      { 
         "count":"9.50647354126",
         "day":"2019-09-25T05:45:00Z"
      },
      { 
         "count":"9.50722503662",
         "day":"2019-09-25T06:00:00Z"
      },
      { 
         "count":"9.50797557831",
         "day":"2019-09-25T06:15:00Z"
      },
      { 
         "count":"9.50797557831",
         "day":"2019-09-25T06:30:00Z"
      },
      { 
         "count":"9.50872612",
         "day":"2019-09-25T06:45:00Z"
      },
      { 
         "count":"9.50985145569",
         "day":"2019-09-25T07:00:00Z"
      },
      { 
         "count":"9.51060199738",
         "day":"2019-09-25T07:15:00Z"
      },
      { 
         "count":"9.51060199738",
         "day":"2019-09-25T07:30:00Z"
      },
      { 
         "count":"9.51135158539",
         "day":"2019-09-25T07:45:00Z"
      },
      { 
         "count":"9.51135158539",
         "day":"2019-09-25T08:00:00Z"
      },
      { 
         "count":"9.51196289062",
         "day":"2019-09-25T08:15:00Z"
      },
      { 
         "count":"9.51285266876",
         "day":"2019-09-25T08:30:00Z"
      },
      { 
         "count":"9.51360321045",
         "day":"2019-09-25T08:45:00Z"
      },
      { 
         "count":"9.51571369171",
         "day":"2019-09-25T09:00:00Z"
      },
      { 
         "count":"9.51758861542",
         "day":"2019-09-25T09:15:00Z"
      },
      { 
         "count":"9.51496315002",
         "day":"2019-09-25T09:30:00Z"
      },
      { 
         "count":"9.51496315002",
         "day":"2019-09-25T09:45:00Z"
      },
      { 
         "count":"9.51547813416",
         "day":"2019-09-25T10:00:00Z"
      },
      { 
         "count":"9.51575946808",
         "day":"2019-09-25T10:15:00Z"
      },
      { 
         "count":"9.51552391052",
         "day":"2019-09-25T10:30:00Z"
      },
      { 
         "count":"9.51693058014",
         "day":"2019-09-25T10:45:00Z"
      },
      { 
         "count":"9.51796245575",
         "day":"2019-09-25T11:00:00Z"
      },
      { 
         "count":"9.51899623871",
         "day":"2019-09-25T11:15:00Z"
      },
      { 
         "count":"9.52040576935",
         "day":"2019-09-25T11:30:00Z"
      },
      { 
         "count":"9.5209236145",
         "day":"2019-09-25T11:45:00Z"
      },
      { 
         "count":"9.5230884552",
         "day":"2019-09-25T12:00:00Z"
      },
      { 
         "count":"9.52337169647",
         "day":"2019-09-25T12:15:00Z"
      },
      { 
         "count":"9.52516174316",
         "day":"2019-09-25T12:30:00Z"
      },
      { 
         "count":"9.52657699585",
         "day":"2019-09-25T12:45:00Z"
      },
      { 
         "count":"9.52860355377",
         "day":"2019-09-25T13:00:00Z"
      },
      { 
         "count":"9.53002071381",
         "day":"2019-09-25T13:15:00Z"
      },
      { 
         "count":"9.53257083893",
         "day":"2019-09-25T13:30:00Z"
      },
      { 
         "count":"9.53346920013",
         "day":"2019-09-25T13:45:00Z"
      },
      { 
         "count":"9.53512191772",
         "day":"2019-09-25T14:00:00Z"
      },
      { 
         "count":"9.54144954681",
         "day":"2019-09-25T14:15:00Z"
      },
      { 
         "count":"9.54046344757",
         "day":"2019-09-25T14:30:00Z"
      },
      { 
         "count":"9.54211902618",
         "day":"2019-09-25T14:45:00Z"
      },
      { 
         "count":"9.54453086853",
         "day":"2019-09-25T15:00:00Z"
      },
      { 
         "count":"9.54581069946",
         "day":"2019-09-25T15:15:00Z"
      },
      { 
         "count":"9.54897975922",
         "day":"2019-09-25T15:30:00Z"
      },
      { 
         "count":"9.55124664307",
         "day":"2019-09-25T15:45:00Z"
      },
      { 
         "count":"9.55366230011",
         "day":"2019-09-25T16:00:00Z"
      },
      { 
         "count":"9.5551738739",
         "day":"2019-09-25T16:15:00Z"
      },
      { 
         "count":"9.55668354034",
         "day":"2019-09-25T16:30:00Z"
      },
      { 
         "count":"9.55819606781",
         "day":"2019-09-25T16:45:00Z"
      },
      { 
         "count":"9.55985736847",
         "day":"2019-09-25T17:00:00Z"
      },
      { 
         "count":"9.5606136322",
         "day":"2019-09-25T17:15:00Z"
      },
      { 
         "count":"9.56136894226",
         "day":"2019-09-25T17:30:00Z"
      },
      { 
         "count":"9.56303215027",
         "day":"2019-09-25T17:45:00Z"
      },
      { 
         "count":"9.5634098053",
         "day":"2019-09-25T18:00:00Z"
      },
      { 
         "count":"9.56363677979",
         "day":"2019-09-25T18:15:00Z"
      },
      { 
         "count":"9.56401443481",
         "day":"2019-09-25T18:30:00Z"
      },
      { 
         "count":"9.56401443481",
         "day":"2019-09-25T18:45:00Z"
      },
      { 
         "count":"9.56439304352",
         "day":"2019-09-25T19:00:00Z"
      },
      { 
         "count":"9.56514835358",
         "day":"2019-09-25T19:15:00Z"
      },
      { 
         "count":"9.56650924683",
         "day":"2019-09-25T19:30:00Z"
      },
      { 
         "count":"9.56462001801",
         "day":"2019-09-25T19:45:00Z"
      },
      { 
         "count":"9.56499767303",
         "day":"2019-09-25T20:00:00Z"
      },
      { 
         "count":"9.56499767303",
         "day":"2019-09-25T20:15:00Z"
      },
      { 
         "count":"9.56462001801",
         "day":"2019-09-25T20:30:00Z"
      },
      { 
         "count":"9.56499767303",
         "day":"2019-09-25T20:45:00Z"
      },
      { 
         "count":"9.56537532806",
         "day":"2019-09-25T21:00:00Z"
      },
      { 
         "count":"9.56499767303",
         "day":"2019-09-25T21:15:00Z"
      },
      { 
         "count":"9.56499767303",
         "day":"2019-09-25T21:30:00Z"
      },
      { 
         "count":"9.56635761261",
         "day":"2019-09-25T21:45:00Z"
      },
      { 
         "count":"9.56673622131",
         "day":"2019-09-25T22:00:00Z"
      },
      { 
         "count":"9.56733989716",
         "day":"2019-09-25T22:15:00Z"
      },
      { 
         "count":"9.56756591797",
         "day":"2019-09-25T22:30:00Z"
      },
      { 
         "count":"9.56832122803",
         "day":"2019-09-25T22:45:00Z"
      },
      { 
         "count":"9.56854724884",
         "day":"2019-09-25T23:00:00Z"
      },
      { 
         "count":"9.56915092468",
         "day":"2019-09-25T23:15:00Z"
      },
      { 
         "count":"9.56990528107",
         "day":"2019-09-25T23:30:00Z"
      },
      { 
         "count":"9.57088661194",
         "day":"2019-09-25T23:45:00Z"
      },
      { 
         "count":"9.57277297974",
         "day":"2019-09-26T00:00:00Z"
      },
      { 
         "count":"9.5733757019",
         "day":"2019-09-26T00:15:00Z"
      },
      { 
         "count":"9.57790279388",
         "day":"2019-09-26T00:30:00Z"
      },
      { 
         "count":"9.57774925232",
         "day":"2019-09-26T00:45:00Z"
      },
      { 
         "count":"9.57737255096",
         "day":"2019-09-26T01:00:00Z"
      },
      { 
         "count":"9.57759666443",
         "day":"2019-09-26T01:15:00Z"
      },
      { 
         "count":"9.57835102081",
         "day":"2019-09-26T01:30:00Z"
      },
      { 
         "count":"9.57835102081",
         "day":"2019-09-26T01:45:00Z"
      },
      { 
         "count":"9.57819652557",
         "day":"2019-09-26T02:00:01Z"
      },
      { 
         "count":"9.5785741806",
         "day":"2019-09-26T02:15:00Z"
      },
      { 
         "count":"9.5785741806",
         "day":"2019-09-26T02:30:00Z"
      },
      { 
         "count":"9.57819652557",
         "day":"2019-09-26T02:45:00Z"
      },
      { 
         "count":"9.57804393768",
         "day":"2019-09-26T03:00:00Z"
      },
      { 
         "count":"9.57766628265",
         "day":"2019-09-26T03:15:00Z"
      },
      { 
         "count":"9.5772895813",
         "day":"2019-09-26T03:30:00Z"
      },
      { 
         "count":"9.57615852356",
         "day":"2019-09-26T03:45:00Z"
      },
      { 
         "count":"9.5757818222",
         "day":"2019-09-26T04:00:00Z"
      },
      { 
         "count":"9.57540416718",
         "day":"2019-09-26T04:15:00Z"
      },
      { 
         "count":"9.57449817657",
         "day":"2019-09-26T04:30:00Z"
      },
      { 
         "count":"9.57412147522",
         "day":"2019-09-26T04:45:00Z"
      },
      { 
         "count":"9.57412147522",
         "day":"2019-09-26T05:00:00Z"
      },
      { 
         "count":"9.57449817657",
         "day":"2019-09-26T05:15:00Z"
      },
      { 
         "count":"9.57412147522",
         "day":"2019-09-26T05:30:00Z"
      },
      { 
         "count":"9.57675933838",
         "day":"2019-09-26T05:45:00Z"
      },
      { 
         "count":"9.57299041748",
         "day":"2019-09-26T06:00:00Z"
      },
      { 
         "count":"9.57336711884",
         "day":"2019-09-26T06:15:00Z"
      },
      { 
         "count":"9.57261371613",
         "day":"2019-09-26T06:30:00Z"
      },
      { 
         "count":"9.57299041748",
         "day":"2019-09-26T06:45:00Z"
      },
      { 
         "count":"9.57261371613",
         "day":"2019-09-26T07:00:00Z"
      },
      { 
         "count":"9.57261371613",
         "day":"2019-09-26T07:15:00Z"
      },
      { 
         "count":"9.57336711884",
         "day":"2019-09-26T07:30:00Z"
      },
      { 
         "count":"9.57299041748",
         "day":"2019-09-26T07:45:00Z"
      },
      { 
         "count":"9.57185935974",
         "day":"2019-09-26T08:00:00Z"
      },
      { 
         "count":"9.57185935974",
         "day":"2019-09-26T08:15:00Z"
      },
      { 
         "count":"9.5722360611",
         "day":"2019-09-26T08:30:00Z"
      },
      { 
         "count":"9.57261371613",
         "day":"2019-09-26T08:45:00Z"
      },
      { 
         "count":"9.5722360611",
         "day":"2019-09-26T09:00:00Z"
      },
      { 
         "count":"9.5722360611",
         "day":"2019-09-26T09:15:00Z"
      },
      { 
         "count":"9.5722360611",
         "day":"2019-09-26T09:30:00Z"
      },
      { 
         "count":"9.57299041748",
         "day":"2019-09-26T09:45:00Z"
      },
      { 
         "count":"9.57261371613",
         "day":"2019-09-26T10:00:00Z"
      },
      { 
         "count":"9.57261371613",
         "day":"2019-09-26T10:15:01Z"
      },
      { 
         "count":"9.5722360611",
         "day":"2019-09-26T10:30:00Z"
      },
      { 
         "count":"9.5731420517",
         "day":"2019-09-26T10:45:00Z"
      },
      { 
         "count":"9.57435417175",
         "day":"2019-09-26T11:00:00Z"
      },
      { 
         "count":"9.5725479126",
         "day":"2019-09-26T11:15:00Z"
      },
      { 
         "count":"9.57323074341",
         "day":"2019-09-26T11:30:00Z"
      },
      { 
         "count":"9.57474136353",
         "day":"2019-09-26T11:45:00Z"
      },
      { 
         "count":"9.57474136353",
         "day":"2019-09-26T12:00:01Z"
      },
      { 
         "count":"9.5743637085",
         "day":"2019-09-26T12:15:00Z"
      },
      { 
         "count":"9.5743637085",
         "day":"2019-09-26T12:30:00Z"
      },
      { 
         "count":"9.57398605347",
         "day":"2019-09-26T12:45:00Z"
      },
      { 
         "count":"9.57360839844",
         "day":"2019-09-26T13:00:00Z"
      },
      { 
         "count":"9.5743637085",
         "day":"2019-09-26T13:15:00Z"
      },
      { 
         "count":"9.57360839844",
         "day":"2019-09-26T13:30:00Z"
      },
      { 
         "count":"9.57247543335",
         "day":"2019-09-26T13:45:00Z"
      },
      { 
         "count":"9.57209777832",
         "day":"2019-09-26T14:00:00Z"
      },
      { 
         "count":"9.57149410248",
         "day":"2019-09-26T14:15:00Z"
      },
      { 
         "count":"9.57217693329",
         "day":"2019-09-26T14:30:00Z"
      },
      { 
         "count":"9.57195186615",
         "day":"2019-09-26T14:45:00Z"
      },
      { 
         "count":"9.5728597641",
         "day":"2019-09-26T15:00:00Z"
      },
      { 
         "count":"9.57392215729",
         "day":"2019-09-26T15:15:00Z"
      },
      { 
         "count":"9.57429981232",
         "day":"2019-09-26T15:30:00Z"
      },
      { 
         "count":"9.57483100891",
         "day":"2019-09-26T15:45:00Z"
      },
      { 
         "count":"9.57801055908",
         "day":"2019-09-26T16:00:00Z"
      },
      { 
         "count":"9.57627296448",
         "day":"2019-09-26T16:15:00Z"
      },
      { 
         "count":"9.57475852966",
         "day":"2019-09-26T16:30:00Z"
      },
      { 
         "count":"9.57377624512",
         "day":"2019-09-26T16:45:00Z"
      },
      { 
         "count":"9.57377624512",
         "day":"2019-09-26T17:00:00Z"
      },
      { 
         "count":"9.57430839539",
         "day":"2019-09-26T17:15:00Z"
      },
      { 
         "count":"9.57355117798",
         "day":"2019-09-26T17:30:00Z"
      },
      { 
         "count":"9.57317256927",
         "day":"2019-09-26T17:45:00Z"
      },
      { 
         "count":"9.57241535187",
         "day":"2019-09-26T18:00:00Z"
      },
      { 
         "count":"9.57256793976",
         "day":"2019-09-26T18:15:00Z"
      },
      { 
         "count":"9.57218933105",
         "day":"2019-09-26T18:30:00Z"
      },
      { 
         "count":"9.57181072235",
         "day":"2019-09-26T18:45:00Z"
      },
      { 
         "count":"9.57143211365",
         "day":"2019-09-26T19:00:00Z"
      },
      { 
         "count":"9.57143211365",
         "day":"2019-09-26T19:15:00Z"
      },
      { 
         "count":"9.57090091705",
         "day":"2019-09-26T19:30:00Z"
      },
      { 
         "count":"9.57014369965",
         "day":"2019-09-26T19:45:00Z"
      },
      { 
         "count":"9.57014369965",
         "day":"2019-09-26T20:00:00Z"
      },
      { 
         "count":"9.56976604462",
         "day":"2019-09-26T20:15:00Z"
      },
      { 
         "count":"9.57052230835",
         "day":"2019-09-26T20:30:00Z"
      },
      { 
         "count":"9.57074928284",
         "day":"2019-09-26T20:45:00Z"
      },
      { 
         "count":"9.57264137268",
         "day":"2019-09-26T21:00:00Z"
      },
      { 
         "count":"9.57604789734",
         "day":"2019-09-26T21:15:00Z"
      },
      { 
         "count":"9.57362365723",
         "day":"2019-09-26T21:30:00Z"
      },
      { 
         "count":"9.57513713837",
         "day":"2019-09-26T21:45:00Z"
      },
      { 
         "count":"9.57611942291",
         "day":"2019-09-26T22:00:00Z"
      },
      { 
         "count":"9.57747840881",
         "day":"2019-09-26T22:15:00Z"
      },
      { 
         "count":"9.57899188995",
         "day":"2019-09-26T22:30:00Z"
      },
      { 
         "count":"9.58035087585",
         "day":"2019-09-26T22:45:00Z"
      },
      { 
         "count":"9.58208656311",
         "day":"2019-09-26T23:00:00Z"
      },
      { 
         "count":"9.58359909058",
         "day":"2019-09-26T23:15:00Z"
      },
      { 
         "count":"9.58457946777",
         "day":"2019-09-26T23:30:00Z"
      },
      { 
         "count":"9.58571243286",
         "day":"2019-09-26T23:45:00Z"
      },
      { 
         "count":"9.58669090271",
         "day":"2019-09-27T00:00:00Z"
      },
      { 
         "count":"9.58707046509",
         "day":"2019-09-27T00:15:00Z"
      },
      { 
         "count":"9.5865354538",
         "day":"2019-09-27T00:30:00Z"
      },
      { 
         "count":"9.5865354538",
         "day":"2019-09-27T00:45:00Z"
      },
      { 
         "count":"9.58600234985",
         "day":"2019-09-27T01:00:00Z"
      },
      { 
         "count":"9.58524703979",
         "day":"2019-09-27T01:15:00Z"
      },
      { 
         "count":"9.58433628082",
         "day":"2019-09-27T01:30:00Z"
      },
      { 
         "count":"9.58509159088",
         "day":"2019-09-27T01:45:00Z"
      },
      { 
         "count":"9.58358097076",
         "day":"2019-09-27T02:00:00Z"
      },
      { 
         "count":"9.5856924057",
         "day":"2019-09-27T02:15:00Z"
      },
      { 
         "count":"9.58455944061",
         "day":"2019-09-27T02:30:00Z"
      },
      { 
         "count":"9.58191585541",
         "day":"2019-09-27T02:45:00Z"
      },
      { 
         "count":"9.58153820038",
         "day":"2019-09-27T03:00:00Z"
      },
      { 
         "count":"9.58062839508",
         "day":"2019-09-27T03:15:00Z"
      },
      { 
         "count":"9.58062839508",
         "day":"2019-09-27T03:30:00Z"
      },
      { 
         "count":"9.57911872864",
         "day":"2019-09-27T03:45:00Z"
      },
      { 
         "count":"9.57949638367",
         "day":"2019-09-27T04:00:00Z"
      },
      { 
         "count":"9.57858753204",
         "day":"2019-09-27T04:15:00Z"
      },
      { 
         "count":"9.57820987701",
         "day":"2019-09-27T04:30:00Z"
      },
      { 
         "count":"9.57820987701",
         "day":"2019-09-27T04:45:00Z"
      },
      { 
         "count":"9.57858753204",
         "day":"2019-09-27T05:00:00Z"
      },
      { 
         "count":"9.57783222198",
         "day":"2019-09-27T05:15:00Z"
      },
      { 
         "count":"9.57858753204",
         "day":"2019-09-27T05:30:00Z"
      },
      { 
         "count":"9.57843399048",
         "day":"2019-09-27T05:45:00Z"
      },
      { 
         "count":"9.57805633545",
         "day":"2019-09-27T06:00:00Z"
      },
      { 
         "count":"9.57881164551",
         "day":"2019-09-27T06:15:00Z"
      },
      { 
         "count":"9.57843399048",
         "day":"2019-09-27T06:30:00Z"
      },
      { 
         "count":"9.57805633545",
         "day":"2019-09-27T06:45:00Z"
      },
      { 
         "count":"9.57805633545",
         "day":"2019-09-27T07:00:00Z"
      },
      { 
         "count":"9.57805633545",
         "day":"2019-09-27T07:15:00Z"
      },
      { 
         "count":"9.58129882812",
         "day":"2019-09-27T07:30:00Z"
      },
      { 
         "count":"9.57790279388",
         "day":"2019-09-27T07:45:00Z"
      },
      { 
         "count":"9.57790279388",
         "day":"2019-09-27T08:00:00Z"
      },
      { 
         "count":"9.57790279388",
         "day":"2019-09-27T08:15:00Z"
      },
      { 
         "count":"9.57752609253",
         "day":"2019-09-27T08:30:00Z"
      },
      { 
         "count":"9.57752609253",
         "day":"2019-09-27T08:45:00Z"
      },
      { 
         "count":"9.5790348053",
         "day":"2019-09-27T09:00:00Z"
      },
      { 
         "count":"9.5790348053",
         "day":"2019-09-27T09:15:00Z"
      },
      { 
         "count":"9.5790348053",
         "day":"2019-09-27T09:30:00Z"
      },
      { 
         "count":"9.5790348053",
         "day":"2019-09-27T09:45:00Z"
      },
      { 
         "count":"9.5790348053",
         "day":"2019-09-27T10:00:00Z"
      },
      { 
         "count":"9.57925891876",
         "day":"2019-09-27T10:15:00Z"
      },
      { 
         "count":"9.5790348053",
         "day":"2019-09-27T10:30:00Z"
      },
      { 
         "count":"9.57941246033",
         "day":"2019-09-27T10:45:00Z"
      },
      { 
         "count":"9.57941246033",
         "day":"2019-09-27T11:00:00Z"
      },
      { 
         "count":"9.57994365692",
         "day":"2019-09-27T11:15:00Z"
      },
      { 
         "count":"9.57956600189",
         "day":"2019-09-27T11:30:00Z"
      },
      { 
         "count":"9.58047485352",
         "day":"2019-09-27T11:45:00Z"
      },
      { 
         "count":"9.58009719849",
         "day":"2019-09-27T12:00:00Z"
      },
      { 
         "count":"9.57949638367",
         "day":"2019-09-27T12:15:00Z"
      },
      { 
         "count":"9.5821390152",
         "day":"2019-09-27T12:30:00Z"
      },
      { 
         "count":"9.58267116547",
         "day":"2019-09-27T12:45:00Z"
      },
      { 
         "count":"9.58055973053",
         "day":"2019-09-27T13:00:00Z"
      },
      { 
         "count":"9.57980442047",
         "day":"2019-09-27T13:15:00Z"
      },
      { 
         "count":"9.57995796204",
         "day":"2019-09-27T13:30:00Z"
      },
      { 
         "count":"9.57973384857",
         "day":"2019-09-27T13:45:00Z"
      },
      { 
         "count":"9.58026599884",
         "day":"2019-09-27T14:00:00Z"
      },
      { 
         "count":"9.58117675781",
         "day":"2019-09-27T14:15:00Z"
      },
      { 
         "count":"9.58057403564",
         "day":"2019-09-27T14:30:00Z"
      },
      { 
         "count":"9.58035087585",
         "day":"2019-09-27T14:45:00Z"
      },
      { 
         "count":"9.58088302612",
         "day":"2019-09-27T15:00:00Z"
      },
      { 
         "count":"9.58103847504",
         "day":"2019-09-27T15:15:00Z"
      },
      { 
         "count":"9.58065891266",
         "day":"2019-09-27T15:30:00Z"
      },
      { 
         "count":"9.5811920166",
         "day":"2019-09-27T15:45:00Z"
      },
      { 
         "count":"9.58134746552",
         "day":"2019-09-27T16:00:00Z"
      },
      { 
         "count":"9.58112239838",
         "day":"2019-09-27T16:15:00Z"
      },
      { 
         "count":"9.58112239838",
         "day":"2019-09-27T16:30:00Z"
      },
      { 
         "count":"9.58165645599",
         "day":"2019-09-27T16:45:00Z"
      },
      { 
         "count":"9.58180999756",
         "day":"2019-09-27T17:00:00Z"
      },
      { 
         "count":"9.58180999756",
         "day":"2019-09-27T17:15:00Z"
      },
      { 
         "count":"9.58105278015",
         "day":"2019-09-27T17:30:00Z"
      },
      { 
         "count":"9.58537387848",
         "day":"2019-09-27T17:45:00Z"
      },
      { 
         "count":"9.58423709869",
         "day":"2019-09-27T18:00:00Z"
      },
      { 
         "count":"9.5823431015",
         "day":"2019-09-27T18:15:00Z"
      },
      { 
         "count":"9.58196353912",
         "day":"2019-09-27T18:30:00Z"
      },
      { 
         "count":"9.58287715912",
         "day":"2019-09-27T18:45:00Z"
      },
      { 
         "count":"9.58249855042",
         "day":"2019-09-27T19:00:00Z"
      },
      { 
         "count":"9.58211898804",
         "day":"2019-09-27T19:15:00Z"
      },
      { 
         "count":"9.58249855042",
         "day":"2019-09-27T19:30:00Z"
      },
      { 
         "count":"9.58174037933",
         "day":"2019-09-27T19:45:00Z"
      },
      { 
         "count":"9.58211898804",
         "day":"2019-09-27T20:00:00Z"
      },
      { 
         "count":"9.58211898804",
         "day":"2019-09-27T20:15:00Z"
      },
      { 
         "count":"9.58174037933",
         "day":"2019-09-27T20:30:00Z"
      },
      { 
         "count":"9.58174037933",
         "day":"2019-09-27T20:45:00Z"
      },
      { 
         "count":"9.58211898804",
         "day":"2019-09-27T21:00:00Z"
      },
      { 
         "count":"9.58211898804",
         "day":"2019-09-27T21:15:00Z"
      },
      { 
         "count":"9.58249855042",
         "day":"2019-09-27T21:30:00Z"
      },
      { 
         "count":"9.58196353912",
         "day":"2019-09-27T21:45:00Z"
      },
      { 
         "count":"9.58105278015",
         "day":"2019-09-27T22:00:00Z"
      },
      { 
         "count":"9.58105278015",
         "day":"2019-09-27T22:15:00Z"
      },
      { 
         "count":"9.5801410675",
         "day":"2019-09-27T22:30:00Z"
      },
      { 
         "count":"9.58074378967",
         "day":"2019-09-27T22:45:00Z"
      },
      { 
         "count":"9.58263683319",
         "day":"2019-09-27T23:00:00Z"
      },
      { 
         "count":"9.57983207703",
         "day":"2019-09-27T23:15:00Z"
      },
      { 
         "count":"9.579454422",
         "day":"2019-09-27T23:30:00Z"
      },
      { 
         "count":"9.57892131805",
         "day":"2019-09-27T23:45:00Z"
      },
      { 
         "count":"9.57929992676",
         "day":"2019-09-28T00:00:00Z"
      },
      { 
         "count":"9.57914543152",
         "day":"2019-09-28T00:15:00Z"
      },
      { 
         "count":"9.57914543152",
         "day":"2019-09-28T00:30:00Z"
      },
      { 
         "count":"9.57899188995",
         "day":"2019-09-28T00:45:00Z"
      },
      { 
         "count":"9.57936954498",
         "day":"2019-09-28T01:00:00Z"
      },
      { 
         "count":"9.57921600342",
         "day":"2019-09-28T01:15:00Z"
      },
      { 
         "count":"9.57997226715",
         "day":"2019-09-28T01:30:00Z"
      },
      { 
         "count":"9.58035087585",
         "day":"2019-09-28T01:45:00Z"
      },
      { 
         "count":"9.57944011688",
         "day":"2019-09-28T02:00:00Z"
      },
      { 
         "count":"9.57944011688",
         "day":"2019-09-28T02:15:00Z"
      },
      { 
         "count":"9.57944011688",
         "day":"2019-09-28T02:30:00Z"
      },
      { 
         "count":"9.57928657532",
         "day":"2019-09-28T02:45:00Z"
      },
      { 
         "count":"9.57928657532",
         "day":"2019-09-28T03:00:00Z"
      },
      { 
         "count":"9.57966423035",
         "day":"2019-09-28T03:15:00Z"
      },
      { 
         "count":"9.57890796661",
         "day":"2019-09-28T03:30:00Z"
      },
      { 
         "count":"9.57875442505",
         "day":"2019-09-28T03:45:00Z"
      },
      { 
         "count":"9.58064460754",
         "day":"2019-09-28T04:00:00Z"
      },
      { 
         "count":"9.58064460754",
         "day":"2019-09-28T04:15:00Z"
      },
      { 
         "count":"9.57875442505",
         "day":"2019-09-28T04:30:00Z"
      },
      { 
         "count":"9.57928657532",
         "day":"2019-09-28T04:45:00Z"
      },
      { 
         "count":"9.57913208008",
         "day":"2019-09-28T05:00:00Z"
      },
      { 
         "count":"9.57950973511",
         "day":"2019-09-28T05:15:00Z"
      },
      { 
         "count":"9.57913208008",
         "day":"2019-09-28T05:30:00Z"
      },
      { 
         "count":"9.57875442505",
         "day":"2019-09-28T05:45:00Z"
      },
      { 
         "count":"9.57875442505",
         "day":"2019-09-28T06:00:00Z"
      },
      { 
         "count":"9.57913208008",
         "day":"2019-09-28T06:15:00Z"
      },
      { 
         "count":"9.57837677002",
         "day":"2019-09-28T06:30:00Z"
      },
      { 
         "count":"9.57762145996",
         "day":"2019-09-28T06:45:00Z"
      },
      { 
         "count":"9.57837677002",
         "day":"2019-09-28T07:00:00Z"
      },
      { 
         "count":"9.57837677002",
         "day":"2019-09-28T07:15:00Z"
      },
      { 
         "count":"9.57799816132",
         "day":"2019-09-28T07:30:00Z"
      },
      { 
         "count":"9.57762145996",
         "day":"2019-09-28T07:45:00Z"
      },
      { 
         "count":"9.57724285126",
         "day":"2019-09-28T08:00:00Z"
      },
      { 
         "count":"9.57686519623",
         "day":"2019-09-28T08:15:00Z"
      },
      { 
         "count":"9.57799816132",
         "day":"2019-09-28T08:30:00Z"
      },
      { 
         "count":"9.57724285126",
         "day":"2019-09-28T08:45:00Z"
      },
      { 
         "count":"9.57762145996",
         "day":"2019-09-28T09:00:00Z"
      },
      { 
         "count":"9.58177757263",
         "day":"2019-09-28T09:15:00Z"
      },
      { 
         "count":"9.57913208008",
         "day":"2019-09-28T09:30:00Z"
      },
      { 
         "count":"9.57762145996",
         "day":"2019-09-28T09:45:00Z"
      },
      { 
         "count":"9.57762145996",
         "day":"2019-09-28T10:00:00Z"
      },
      { 
         "count":"9.57686519623",
         "day":"2019-09-28T10:15:00Z"
      },
      { 
         "count":"9.57739639282",
         "day":"2019-09-28T10:30:00Z"
      },
      { 
         "count":"9.57701778412",
         "day":"2019-09-28T10:45:00Z"
      },
      { 
         "count":"9.57739639282",
         "day":"2019-09-28T11:00:00Z"
      },
      { 
         "count":"9.57739639282",
         "day":"2019-09-28T11:15:00Z"
      },
      { 
         "count":"9.57739639282",
         "day":"2019-09-28T11:30:00Z"
      },
      { 
         "count":"9.57739639282",
         "day":"2019-09-28T11:45:01Z"
      },
      { 
         "count":"9.57701778412",
         "day":"2019-09-28T12:00:00Z"
      },
      { 
         "count":"9.57701778412",
         "day":"2019-09-28T12:15:00Z"
      },
      { 
         "count":"9.57664012909",
         "day":"2019-09-28T12:30:00Z"
      },
      { 
         "count":"9.57664012909",
         "day":"2019-09-28T12:45:00Z"
      },
      { 
         "count":"9.57717132568",
         "day":"2019-09-28T13:00:00Z"
      },
      { 
         "count":"9.57679367065",
         "day":"2019-09-28T13:15:00Z"
      },
      { 
         "count":"9.57641506195",
         "day":"2019-09-28T13:30:00Z"
      },
      { 
         "count":"9.57679367065",
         "day":"2019-09-28T13:45:00Z"
      },
      { 
         "count":"9.57603740692",
         "day":"2019-09-28T14:00:00Z"
      },
      { 
         "count":"9.57754993439",
         "day":"2019-09-28T14:15:00Z"
      },
      { 
         "count":"9.57944011688",
         "day":"2019-09-28T14:30:00Z"
      },
      { 
         "count":"9.57770347595",
         "day":"2019-09-28T14:45:00Z"
      },
      { 
         "count":"9.57694721222",
         "day":"2019-09-28T15:00:00Z"
      },
      { 
         "count":"9.57694721222",
         "day":"2019-09-28T15:15:00Z"
      },
      { 
         "count":"9.57694721222",
         "day":"2019-09-28T15:30:00Z"
      },
      { 
         "count":"9.57619094849",
         "day":"2019-09-28T15:45:00Z"
      },
      { 
         "count":"9.57656860352",
         "day":"2019-09-28T16:00:00Z"
      },
      { 
         "count":"9.57619094849",
         "day":"2019-09-28T16:15:00Z"
      },
      { 
         "count":"9.57581233978",
         "day":"2019-09-28T16:30:01Z"
      },
      { 
         "count":"9.57581233978",
         "day":"2019-09-28T16:45:00Z"
      },
      { 
         "count":"9.57581233978",
         "day":"2019-09-28T17:00:00Z"
      },
      { 
         "count":"9.57581233978",
         "day":"2019-09-28T17:15:00Z"
      },
      { 
         "count":"9.57581233978",
         "day":"2019-09-28T17:30:00Z"
      },
      { 
         "count":"9.57656860352",
         "day":"2019-09-28T17:45:00Z"
      },
      { 
         "count":"9.57656860352",
         "day":"2019-09-28T18:00:00Z"
      },
      { 
         "count":"9.57581233978",
         "day":"2019-09-28T18:15:00Z"
      },
      { 
         "count":"9.57565975189",
         "day":"2019-09-28T18:30:00Z"
      },
      { 
         "count":"9.57565975189",
         "day":"2019-09-28T18:45:00Z"
      },
      { 
         "count":"9.57603740692",
         "day":"2019-09-28T19:00:00Z"
      },
      { 
         "count":"9.57565975189",
         "day":"2019-09-28T19:15:00Z"
      },
      { 
         "count":"9.57981872559",
         "day":"2019-09-28T19:30:00Z"
      },
      { 
         "count":"9.57830619812",
         "day":"2019-09-28T19:45:00Z"
      },
      { 
         "count":"9.57626247406",
         "day":"2019-09-28T20:00:00Z"
      },
      { 
         "count":"9.57664012909",
         "day":"2019-09-28T20:15:00Z"
      },
      { 
         "count":"9.57739639282",
         "day":"2019-09-28T20:30:00Z"
      },
      { 
         "count":"9.57815265656",
         "day":"2019-09-28T20:45:00Z"
      },
      { 
         "count":"9.57853031158",
         "day":"2019-09-28T21:00:00Z"
      },
      { 
         "count":"9.57837677002",
         "day":"2019-09-28T21:15:00Z"
      },
      { 
         "count":"9.57724285126",
         "day":"2019-09-28T21:30:00Z"
      },
      { 
         "count":"9.57799816132",
         "day":"2019-09-28T21:45:00Z"
      },
      { 
         "count":"9.57875442505",
         "day":"2019-09-28T22:00:00Z"
      },
      { 
         "count":"9.57837677002",
         "day":"2019-09-28T22:15:00Z"
      },
      { 
         "count":"9.57950973511",
         "day":"2019-09-28T22:30:00Z"
      },
      { 
         "count":"9.57860088348",
         "day":"2019-09-28T22:45:00Z"
      },
      { 
         "count":"9.57973384857",
         "day":"2019-09-28T23:00:00Z"
      },
      { 
         "count":"9.57973384857",
         "day":"2019-09-28T23:15:00Z"
      },
      { 
         "count":"9.58086776733",
         "day":"2019-09-28T23:30:00Z"
      },
      { 
         "count":"9.58124542236",
         "day":"2019-09-28T23:45:00Z"
      }
   ];

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xValue = d => new Date(d.day);
  const xAxisLabel = 'Time';

  const yValue = d => d.count;
  const yAxisLabel = 'count';

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xAxisTickFormat = timeFormat("%d %b")
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const [start, stop] = xScale.domain();
  
  const binnedData = bin()
    .value(xValue)
    .domain(xScale.domain())
    .thresholds(timeMinutes(start, stop))(data)
    .map(d => ({
      y: mean(d, yValue),
      x0: d.x0,
      x1: d.x1
    }));
  console.log("innerHeight")
   const yScale = scaleLinear()
    .domain([0, max(binnedData, d => d.y)])
    .range([innerHeight, 0]);
  
  console.log("binneddata",binnedData)
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={5}
        />
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight /
            2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        <Marks
          binnedData={binnedData}
          xScale={xScale}
          yScale={yScale}
          tooltipFormat={d => d}
          circleRadius={2}
          innerHeight={innerHeight}
        />
        
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
